summaryrefslogtreecommitdiff
path: root/src/mongo/s/query/cluster_client_cursor_impl.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/s/query/cluster_client_cursor_impl.h')
-rw-r--r--src/mongo/s/query/cluster_client_cursor_impl.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/mongo/s/query/cluster_client_cursor_impl.h b/src/mongo/s/query/cluster_client_cursor_impl.h
index ecb7535715c..9d9168d6afb 100644
--- a/src/mongo/s/query/cluster_client_cursor_impl.h
+++ b/src/mongo/s/query/cluster_client_cursor_impl.h
@@ -121,7 +121,7 @@ public:
bool shouldOmitDiagnosticInformation() const final;
- std::unique_ptr<telemetry::RequestShapifier> getRequestShapifier() final;
+ std::unique_ptr<query_stats::RequestShapifier> getRequestShapifier() final;
public:
/**
@@ -186,12 +186,12 @@ private:
bool _shouldOmitDiagnosticInformation = false;
// If boost::none, telemetry should not be collected for this cursor.
- boost::optional<std::size_t> _telemetryStoreKeyHash;
- // TODO: SERVER-73152 remove telemetryStoreKey when RequestShapifier is used for agg.
- boost::optional<BSONObj> _telemetryStoreKey;
+ boost::optional<std::size_t> _queryStatsStoreKeyHash;
+ // TODO: SERVER-73152 remove queryStatsStoreKey when RequestShapifier is used for agg.
+ boost::optional<BSONObj> _queryStatsStoreKey;
// The RequestShapifier used by telemetry to shapify the request payload into the telemetry
// store key.
- std::unique_ptr<telemetry::RequestShapifier> _telemetryRequestShapifier;
+ std::unique_ptr<query_stats::RequestShapifier> _queryStatsRequestShapifier;
// Tracks if kill() has been called on the cursor. Multiple calls to kill() is an error.
bool _hasBeenKilled = false;